@@ -1,8 +1,8 @@
-/* $Id: upnpdev.h,v 1.2 2018/04/06 10:53:15 nanard Exp $ */
+/* $Id: upnpdev.h,v 1.4 2021/08/21 09:45:01 nanard Exp $ */
 /* Project : miniupnp
- * Web : http://miniupnp.free.fr/
+ * Web : http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
  * Author : Thomas BERNARD
- * copyright (c) 2005-2018 Thomas Bernard
+ * copyright (c) 2005-2021 Thomas Bernard
  * This software is subjet to the conditions detailed in the
  * provided LICENSE file. */
 #ifndef UPNPDEV_H_INCLUDED
@@ -20,7 +20,15 @@ struct UPNPDev {
 	char * st;
 	char * usn;
 	unsigned int scope_id;
-	char buffer[3];
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+	/* C99 flexible array member */
+	char buffer[];
+#elif defined(__GNUC__)
+	char buffer[0];
+#else
+	/* Fallback to a hack */
+	char buffer[1];
+#endif
 };
 
 /* freeUPNPDevlist()
